@@ -39,7 +39,7 @@ class QueriesService(
         """Refresh a query"""
         return self.__base.post(f"{self.endpoint}/{query_id}/results", dict(max_age=0))
 
-    def fork(self, query_id: int, new_name: Optional[str]) -> Dict:
+    def fork(self, query_id: int, new_name: str = None) -> Dict:
         """Fork a query with a new name if provided"""
         new_q = self.__base.post(f"{self.endpoint}/{query_id}/fork", {"id": query_id})
 
@@ -61,8 +61,10 @@ class QueriesService(
         self,
         *,
         query: Dict,
+        new_name: str = None,
         table_map: Dict[str, str],
         tags: List[str],
+        new_data_source_id: Optional[int] = None,
         publish: bool = True,
     ) -> Dict:
         """
@@ -70,8 +72,10 @@ class QueriesService(
 
         Args:
             query(Dict): query data object
+            new_name(str): new query name (optional)
             table_map(Dict): mapping of old to new tables
             tags(List): tags to add to new query
+            new_data_source_id(int): new data source id (optional)
             publish(bool): whether to publish the new query
 
         Returns:
@@ -85,16 +89,23 @@ class QueriesService(
             >>> }
             >>> tags = ["tag1", "tag2"]
             >>> new_query = queries.duplicate_query_table(
-            >>>     query=query, table_map=table_map, tags=tags, publish=True
+            >>>     query=query,
+            >>>     new_name="new_query_name",
+            >>>     table_map=table_map,
+            >>>     new_data_source_id=rd.data_sources.get_by_name("new_data_source").id,
+            >>>     tags=tags,
             >>> )
         """
 
-        new_id = self.fork(query.get("id")).get("id")
+        new_id = self.fork(query.get("id"), new_name).get("id")
 
         # update query
         new_query = self.get(new_id)
         new_query["name"] = query.get("name")
         new_query["tags"] = tags
+        new_query["data_source_id"] = (
+            new_data_source_id if new_data_source_id else query.get("data_source_id")
+        )
 
         for old, new in list(table_map.items()):
             new_query["query"] = new_query.get("query").replace(old, new)
